@@ -1,3 +1,13 @@
+/***********************************************************************
+*
+* asciibcd.h - IBM 7090 emulator ascii conversion tables.
+*
+* Changes:
+*   ??/??/??   PP    Original. Version 1.0.0
+*   01/28/05   DGP   Changed to make IBSYS codes primary and other is alt.
+*                    Also, changed alt codes for source tape correctness.
+*	
+***********************************************************************/
 
 /*
  * BCD to ASCII table
@@ -5,7 +15,7 @@
  * Uses FORTRAN 026 codes plus special IBM PC graphics for weird codes.
  */
 
-unsigned char asciibcd[64] = {
+uint8 asciibcd[64] = {
 /* 00 */ '0', '1', '2', '3', '4', '5', '6', '7',
 /* 10 */ '8', '9', ' ', '=', '\'', ' ', ' ', ' ',
 /* 20 */ '+', 'A', 'B', 'C', 'D', 'E', 'F', 'G',
@@ -16,20 +26,7 @@ unsigned char asciibcd[64] = {
 /* 70 */ 'Y', 'Z', ' ', ',', '(', ' ', ' ', ' '
 };
 
-#if 0
-unsigned char asciialt[64] = {
-/* 00 */ '0', '1', '2', '3', '4', '5', '6', '7',
-/* 10 */ '8', '9', ' ', '=', '\'', ' ', ' ', ' ',
-/* 20 */ '+', 'A', 'B', 'C', 'D', 'E', 'F', 'G',
-/* 30 */ 'H', 'I', ' ', '.', ')', ' ', ' ', ' ',
-/* 40 */ '-', 'J', 'K', 'L', 'M', 'N', 'O', 'P',
-/* 50 */ 'Q', 'R', ' ', '$', '*', ' ', ' ', ' ',
-/* 60 */ ' ', '/', 'S', 'T', 'U', 'V', 'W', 'X',
-/* 70 */ 'Y', 'Z', ' ', ',', '(', ' ', ' ', ' '
-};
-#endif
-
-unsigned char asciialt[64] = {
+uint8 asciialt[64] = {
 /* 00 */ ' ', '1', '2', '3', '4', '5', '6', '7',
 /* 10 */ '8', '9', '0', '=', '\'', ':', '>', '{',
 /* 20 */ ' ', '/', 'S', 'T', 'U', 'V', 'W', 'X',
